<?php

declare(strict_types=1);

namespace Drupal\inline_image_saver\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\DependencyInjection\AutowireTrait;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\RedundantEditableConfigNamesTrait;

/**
 * Configures inline_image_saver.settings for this site.
 */
class InlineImageSaverSettingsForm extends ConfigFormBase {

  use AutowireTrait;
  use RedundantEditableConfigNamesTrait;

  /**
   * The module config name.
   */
  public const CONFIG_NAME = 'inline_image_saver.settings';

  /**
   * Constructs the object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config manager.
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entityFieldManager
   *   The entity field manager.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
    TypedConfigManagerInterface $typedConfigManager,
    protected EntityFieldManagerInterface $entityFieldManager,
  ) {
    parent::__construct($configFactory, $typedConfigManager);
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'inline_image_saver_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['validation'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable validation'),
      '#config_target' => static::CONFIG_NAME . ':validation',
    ];
    $form['try_download'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Try to download missing images'),
      '#config_target' => static::CONFIG_NAME . ':try_download',
    ];
    $form['allow_if_downloadable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Skip validation if image is downloadable'),
      '#config_target' => static::CONFIG_NAME . ':allow_if_downloadable',
      '#states' => [
        'visible' => [
          ':input[name="validation"]' => ['checked' => TRUE],
          ':input[name="try_download"]' => ['checked' => TRUE],
        ],
      ],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);
    $this->entityFieldManager->clearCachedFieldDefinitions();
  }

}
