<?php

declare(strict_types=1);

namespace Drupal\inline_image_saver;

use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\file\FileInterface;
use Drupal\text\Plugin\Field\FieldType\TextItemBase;

/**
 * Provides an interface for the inline image savers.
 */
interface InlineImageSaverInterface {

  /**
   * The default upload directory name.
   */
  public const DEFAULT_DIR_NAME = 'inline-image-saver';

  /**
   * Downloads inline images for an entity if necessary and updates the markup.
   */
  public function fixEntity(FieldableEntityInterface $entity, bool $remove_broken = FALSE, string $broken_text = ''): void;

  /**
   * Downloads inline images for an item if necessary and updates the markup.
   */
  public function fixItem(TextItemBase $item, bool $remove_broken = FALSE, string $broken_text = ''): void;

  /**
   * Checks if an image is a valid file entity.
   */
  public function isValidInlineImage(\DOMElement $img): bool;

  /**
   * Downloads an inline image for a text item.
   */
  public function downloadInlineImage(TextItemBase $item, string $src, bool $to_temp = FALSE): ?FileInterface;

  /**
   * Returns the text value of a text item if it contains inline images.
   */
  public function getTextItemDom(TextItemBase $item): ?\DOMDocument;

  /**
   * Sets the text value of a text item.
   */
  public function setTextItemDom(TextItemBase $item, \DOMDocument $value): void;

}
